==> haskell-mysql-simple-0.4.5-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql-simple
version:              0.4.5
visibility:           public
id:                   mysql-simple-0.4.5-9OiX3JKQxtPJM1WjLYRM0v
key:                  mysql-simple-0.4.5-9OiX3JKQxtPJM1WjLYRM0v
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  3dae708574a21cd6ba7691c2658fbb0d
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

import-dirs:          /usr/lib/ghc-8.10.3/site-local/mysql-simple-0.4.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/mysql-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/mysql-simple-0.4.5
hs-libraries:         HSmysql-simple-0.4.5-9OiX3JKQxtPJM1WjLYRM0v
depends:
    attoparsec-0.13.2.4-JZoYjKctPXo3EQxEpGFo7r base-4.14.1.0
    base16-bytestring-1.0.1.0-9cyLOhkgFxfC95uDaqg8ns
    blaze-builder-0.4.1.0-AY5yPUQEaMfQ8f1oQxUHw
    blaze-textual-0.2.1.0-9yzLK1qOMwVJPmRiv9UxgN bytestring-0.10.12.0
    containers-0.6.2.1 mysql-0.1.7.2-FSXbx4xtrxeCbXnhFmFhEu
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    pcre-light-0.4.1.0-388OLjEtaWvLYgh7Bq2Puc text-1.2.4.1 time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.5-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql-simple
version:              0.4.5
visibility:           public
id:                   mysql-simple-0.4.5-9uHDJ9V2Z4kJvp8eefc4V1
key:                  mysql-simple-0.4.5-9uHDJ9V2Z4kJvp8eefc4V1
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  96ed2d701f01ae11e4a1a75f72f38bdb
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

import-dirs:          /usr/lib/ghc-8.10.3/site-local/mysql-simple-0.4.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/mysql-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/mysql-simple-0.4.5
hs-libraries:         HSmysql-simple-0.4.5-9uHDJ9V2Z4kJvp8eefc4V1
depends:
    attoparsec-0.13.2.4-39TJgLEc6zy21miTrRuwax base-4.14.1.0
    base16-bytestring-1.0.1.0-2ratTuc7ZonJBydZGuukUt
    blaze-builder-0.4.1.0-AY5yPUQEaMfQ8f1oQxUHw
    blaze-textual-0.2.1.0-3DkUrlDqKPB8UsH9QxrnSY bytestring-0.10.12.0
    containers-0.6.2.1 mysql-0.1.7.2-2UJ86FGLNCpGwpqAyayVIW
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    pcre-light-0.4.1.0-388OLjEtaWvLYgh7Bq2Puc text-1.2.4.1 time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
